@@ -6,15 +6,16 @@ from fastapi.security import OAuth2, SecurityScopes
 from jose import JWTError, jwt
 from pydantic import ValidationError
 
-from .models import AuthUser
 from fa_common import (
-    async_get,
-    force_async,
-    logger as LOG,
     ForbiddenError,
     UnauthorizedError,
+    async_get,
+    force_async,
     get_settings,
 )
+from fa_common import logger as LOG
+
+from .models import AuthUser
 
 oauth2_scheme = OAuth2(
     flows=OAuthFlows(
