@@ -1,4 +1,5 @@
 import asyncio
+import datetime
 from io import BytesIO
 from typing import List, Optional, Union
 
@@ -7,9 +8,15 @@ from google.cloud import storage
 from google.cloud.exceptions import Conflict, GoogleCloudError, NotFound
 from google.cloud.storage.bucket import Blob, Bucket
 
-from fa_common import StorageError, force_async, get_current_app, get_settings
-from fa_common import logger as LOG
-from fa_common import sizeof_fmt
+from fa_common import (
+    StorageError,
+    FileDownloadRef,
+    force_async,
+    get_current_app,
+    get_settings,
+    logger as LOG,
+    sizeof_fmt,
+)
 
 from .base_client import BaseClient
 from .model import File
@@ -255,6 +262,16 @@ class GoogleStorageClient(BaseClient):
             )
         LOG.debug(f"{from_path} copied to {to_path}")
 
+    async def create_temp_file_ref(self, bucket: str, path: str) -> File:
+        blob = await self._get_blob(bucket, path)
+        expire_time = datetime.timedelta(hours=3)
+
+        url = blob.generate_signed_url(expiration=expire_time, version="v4")
+        LOG.info(f"Created url: {url} for file download")
+        file = self.blob_to_file(blob, bucket)
+        file.url = url
+        return file
+
 
 class FirebaseStorageClient(GoogleStorageClient):
     """
