@@ -2,17 +2,17 @@ import os
 import pytest
 
 import oyaml as yaml
-from fa_common import create_app, start_app, utils, force_sync
+from fa_common import create_app, start_app, utils, force_sync, FileDownloadRef
 from fa_common.workflow import (
     get_workflow_client,
     run_job,
     ScidraModule,
-    FileDownloadRef,
     get_job_run,
     get_job_log,
     create_workflow_project,
     WorkflowProject,
 )
+from fa_common.storage import File
 from .conftest import get_env_file, TEST_GITLAB_PROJECT, TEST_GITLAB_BRANCH
 
 dirname = os.path.dirname(__file__)
@@ -46,7 +46,7 @@ async def test_job_create(ensure_test_gitlab):
 
     module = ScidraModule(
         name="noise-detection",
-        docker_image="docker-registry.it.csiro.au/scidra-modules/noise-detection:latest",
+        docker_image="registry.gitlab.com/csiro-geoanalytics/gpt/modules/noise-detection:latest",
     )
     job_data = {
         "window_channels": 4,
@@ -57,11 +57,11 @@ async def test_job_create(ensure_test_gitlab):
         "crossover_threshold": 0.003,
     }
     files = [
-        FileDownloadRef(
-            name="data_file",
+        File(
+            id="data_file",
+            name="data_file.csv",
             url="https://firebasestorage.googleapis.com/v0/b/gp-toolkit-staging.appspot.com/o/"
             + "unit_test_data%2Fnd_test_data.csv?alt=media&token=96a65aa1-9e34-4a37-9bc7-7eac4f14847e",
-            extension="csv",
         )
     ]
 
@@ -90,7 +90,7 @@ async def test_job_create_async(ensure_test_gitlab):
 
     module = ScidraModule(
         name="noise-detection",
-        docker_image="docker-registry.it.csiro.au/scidra-modules/noise-detection:latest",
+        docker_image="registry.gitlab.com/csiro-geoanalytics/gpt/modules/noise-detection:latest",
     )
     job_data = {
         "window_channels": 4,
@@ -101,11 +101,11 @@ async def test_job_create_async(ensure_test_gitlab):
         "crossover_threshold": 0.003,
     }
     files = [
-        FileDownloadRef(
-            name="data_file",
+        File(
+            id="data_file",
+            name="data_file.csv",
             url="https://firebasestorage.googleapis.com/v0/b/gp-toolkit-staging.appspot.com/o/"
             + "unit_test_data%2Fnd_test_data.csv?alt=media&token=96a65aa1-9e34-4a37-9bc7-7eac4f14847e",
-            extension="csv",
         )
     ]
 
